#!/usr/bin/perl -w
# Copyright 2004 ©HRMills
# 
# Released under the BSD license. See the file LICENSE for more details.

package DVBScripts;

BEGIN {
    use Exporter ();
    our ($VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS);
    @EXPORT = qw(&get_opts &get_channels &on_same_mux);
    $VERSION = 0.2.0;
    @ISA = qw(Exporter);
}
our @EXPORT_OK;

our $Version = "0.2.0";

sub get_opts()
{
    my %opts = ('recorddir' => '/media/local/video',
		'channels' => $ENV{HOME} . '/.tzap/channels.conf',
		'channelmap' => $ENV{HOME} . '/.dvb-channels.map',
		'dbdir' => '/var/spool/dvb-scripts',
		);

    parse_opts(\%opts, "/etc/dvb-scripts.conf");
    parse_opts(\%opts, $ENV{HOME} . "/.dvb-scripts.conf");

    return %opts;
}

sub parse_opts($$)
{
    my ($opts, $file) = @_;

    if( ! -e $file )
    {
	return;
    }

    my $end = '[[:space:]]*=[[:space:]]*(.*)[[:space:]]*$';

    open FILE, "<", $file;

    while(<FILE>)
    {
	if(m/^[[:space:]]*$/ || m/^[[:space:]]*\#/)
	{
	    next;
	}
	
	if(m/^RecordDir$end/)
	{
	    ${$opts}{'recorddir'} = $1;
	    ${$opts}{'recorddir'} =~ s/~/$ENV{'HOME'}/;
	}
	elsif(m/^ChannelsConf$end/)
	{
	    ${$opts}{'channels'} = $1;
	    ${$opts}{'channels'} =~ s/~/$ENV{'HOME'}/;
	}
	elsif(m/^ChannelMap$end/)
	{
	    ${$opts}{'channelmap'} = $1;
	    ${$opts}{'channelmap'} =~ s/~/$ENV{'HOME'}/;
	}
	elsif(m/^DBDir$end/)
	{
	    ${$opts}{'dbdir'} = $1;
	    ${$opts}{'dbdir'} =~ s/~/$ENV{'HOME'}/;
	}
	else
	{
	    print STDERR "Unknown configuration option in config file ";
	    print STDERR $file, " at line ", $., "\n";
	}
    }

    close FILE;
}

sub get_channels($)
{
    my %opts = %{$_[0]};

    my %c;

    if(! -e $opts{'channels'} )
    {
	print STDERR "Can't find channels file ", $opts{'channels'};
	print STDERR "\n";
    }

    open CHANS, "<", $opts{'channels'};

    while(<CHANS>)
    {
	chomp;
	if(m/^([^:]+):([^:]+)[[:digit:]]{3}:([^:]+:){8}([^:]+):([^:]+):([^:]+)$/)
	{
	    $c{$1} = {
		'name' => $1,
		'frequency' => $2,
		'vpid' => $4,
		'apid' => $5,
	    };
	}
	else
	{
	    print STDERR "Unusual line in ChannelsConf file ";
	    print STDERR $opts{'channels'}, " line number ", $.;
	    print STDERR ". Line was:\n", $_;
	}
    }

    close CHANS;

    if(-e $opts{'channelmap'})
    {
	open MAP, "<", $opts{'channelmap'};
	while(<MAP>)
	{
	    chomp;

	    if(m/^\#/ || m/^[[:space:]]*$/)
	    {
		next;
	    }

	    if(m/^([^:]+):([^:]+)$/)
	    {
		if(exists($c{$2}))
		{
		    $c{$1} = $c{$2};
		}
		else
		{
		    print STDERR "In ChannelMap file ", $opts{'channelmap'};
		    print STDERR " line number ", $., ". '", $2;
		    print STDERR "' is not a known channel.\n";
		}
	    }
	    else
	    {
		print STDERR "Unusual line in ChannelMap file ";
		print STDERR $opts{'channelmap'}, " line number ";
		print STDERR $., ".\n";
	    }
	}
	close MAP;
    }

    return %c;
}

sub on_same_mux
{
    my $channels = shift;
    my %channels = %{$channels};
    my $mux = "";

    foreach (@_)
    {
	if($mux eq "")
	{
	    $mux = ${channels{$_}}{'frequency'};
	}
	if($mux ne ${channels{$_}}{'frequency'})
	{
	    return 0;
	}
    }

    return 1;
}

1;

