#!/usr/bin/perl -w
# Copyright 2004 ©HRMills
# 
# Released under the BSD license. See the file LICENSE for more details.

package DVBScripts::Recordings;

use Date::Manip;

BEGIN {
    use Exporter ();
    our ($VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS);
    @EXPORT = qw(&load_recordings &save_recordings &human_format);
    $VERSION = 0.2.0;
    @ISA = qw(Exporter);
}
our @EXPORT_OK;

sub load_recordings($)
{
    my ($opts) = @_;
    my %opts = %$opts;

    my @recs = ();

    # Note: no file locking here. Not multi-user safe.
    if(open RECS, "<", $opts{'dbdir'} . '/recordings')
    {
	scalar <RECS>;
	my $fileversion = $_;

	while(<RECS>)
	{
	    chomp;
	    my %rec;
	    my @ents = split m/:/;
	    $rec{'starttime'} = ParseDate(shift @ents);
	    $rec{'endtime'} = ParseDate(shift @ents);
	    $rec{'startid'} = shift @ents;
	    $rec{'endid'} = shift @ents;
	    $rec{'filename'} = shift @ents;
	    $rec{'channels'} = \@ents;
	    push @recs, \%rec;
	}

	close RECS;
    }

    return @recs;
}

sub save_recordings($$)
{
    my ($optsr, $recsr) = @_;
    my %opts = %$optsr;

    rename $opts{'dbdir'} . '/recordings', $opts{'dbdir'} . '/recordings.bak';

    open RECS, ">", $opts{'dbdir'} . '/recordings';
    print RECS "0.2\n";
    foreach (@$recsr)
    {
	print RECS UnixDate(${$_}{'starttime'}, "%q");
	print RECS ":", UnixDate(${$_}{'endtime'}, "%q");
	print RECS ":", ${$_}{'startid'};
	print RECS ":", ${$_}{'endid'};
	print RECS ":", ${$_}{'filename'};
	foreach (@{${$_}{'channels'}})
	{
	    print RECS ":", $_;
	}
	print RECS "\n";
    }
    close RECS;
}

sub list_pids($$)
{
    my ($ret, $channels, $argvr) = ("", @_);

    foreach (@$argvr)
    {
	if($$channels{$_}{'apid'} ne 0)
	{
	    $ret .= " " . $$channels{$_}{'apid'};
	}
	if($$channels{$_}{'vpid'} ne 0)
	{
	    $ret .= " " . $$channels{$_}{'vpid'};
	}
    }

    return $ret;
}

sub human_format($)
{
    my %rec = %{$_[0]};
    my $s = "";

    $s .= join(" ", @{$rec{'channels'}});
    $s .= " to file " . $rec{'filename'} . " between ";
    $s .= UnixDate($rec{'starttime'}, "%d/%m/%Y %R") . " and ";
    $s .= UnixDate($rec{'endtime'}, "%d/%m/%Y %R");
}

1;
